import logging

import aioxmpp


async def send_notification(
    jid: str, password: str, to: str, show_name: str, episode: int
):
    """Sends a notification of a new show download to @to using the account @jid:@password.
    @show_name is the name of show. @episode is the number of the episode that was just downloaded.
    """
    logging.getLogger("akibabot.xmpp").debug("Sending notification via XMPP")
    client = aioxmpp.PresenceManagedClient(
        aioxmpp.JID.fromstr(jid),
        aioxmpp.make_security_layer(password),
    )

    async with client.connected() as stream:
        msg = aioxmpp.Message(
            to=aioxmpp.JID.fromstr(to),
            type_=aioxmpp.MessageType.CHAT,
        )
        msg.body[
            None
        ] = f"Episode {episode} of {show_name} is now downloaded and available!"
        await stream.send(msg)
